@@ -229,16 +229,12 @@ class ExceptionRaiseRefVisitor(BaseVisitor):
     def visit_call(self, node: nodes.Call) -> None:
         if isinstance(node.func, nodes.Name):
             self.visit_name(node.func)
-        if (
-            len(node.args) > 1
-            and isinstance(node.args[0], nodes.Const)
-            and isinstance(node.args[0].value, str)
-        ):
-            msg = node.args[0].value
-            if "%" in msg or ("{" in msg and "}" in msg):
-                self._checker.add_message(
-                    "raising-format-tuple", node=self._node, confidence=HIGH
-                )
+        match node.args:
+            case [nodes.Const(value=str() as msg), _, *_]:
+                if "%" in msg or ("{" in msg and "}" in msg):
+                    self._checker.add_message(
+                        "raising-format-tuple", node=self._node, confidence=HIGH
+                    )
 
 
 class ExceptionRaiseLeafVisitor(BaseVisitor):
@@ -405,9 +401,9 @@ class ExceptionsChecker(checkers.BaseChecker):
                 confidence=HIGH,
             )
         elif (
-            isinstance(node.exc, nodes.Call)
-            and isinstance(node.exc.func, nodes.Name)
-            or isinstance(node.exc, nodes.Name)
+            isinstance(node.exc, nodes.Call) and isinstance(node.exc.func, nodes.Name)
+        ) or (
+            isinstance(node.exc, nodes.Name)
             and node.exc.name != containing_except_node.name.name
         ):
             # We have a `raise SomeException(whatever)` or a `raise SomeException`
@@ -432,7 +428,13 @@ class ExceptionsChecker(checkers.BaseChecker):
                 return
             if all(
                 node
-                and (utils.inherit_from_std_ex(node) or not utils.has_known_bases(node))
+                and (
+                    utils.inherit_from_std_ex(node)
+                    or (
+                        isinstance(node, nodes.ClassDef)
+                        and not utils.has_known_bases(node)
+                    )
+                )
                 for node in inferred
             ):
                 return
@@ -441,25 +443,27 @@ class ExceptionsChecker(checkers.BaseChecker):
             # Don't emit the warning if the inferred stmt
             # is None, but the exception handler is something else,
             # maybe it was redefined.
-            if isinstance(exc, nodes.Const) and exc.value is None:
-                if (
-                    isinstance(handler.type, nodes.Const) and handler.type.value is None
-                ) or handler.type.parent_of(exc):
-                    # If the exception handler catches None or
-                    # the exception component, which is None, is
-                    # defined by the entire exception handler, then
-                    # emit a warning.
+            match exc:
+                case nodes.Const(value=None):
+                    if (
+                        isinstance(handler.type, nodes.Const)
+                        and handler.type.value is None
+                    ) or handler.type.parent_of(exc):
+                        # If the exception handler catches None or
+                        # the exception component, which is None, is
+                        # defined by the entire exception handler, then
+                        # emit a warning.
+                        self.add_message(
+                            "catching-non-exception",
+                            node=handler.type,
+                            args=(part.as_string(),),
+                        )
+                case _:
                     self.add_message(
                         "catching-non-exception",
                         node=handler.type,
                         args=(part.as_string(),),
                     )
-            else:
-                self.add_message(
-                    "catching-non-exception",
-                    node=handler.type,
-                    args=(part.as_string(),),
-                )
             return
 
         if (
@@ -612,9 +616,9 @@ class ExceptionsChecker(checkers.BaseChecker):
                         continue
 
                     exc_ancestors = [
-                        anc
-                        for anc in exception.ancestors()
-                        if isinstance(anc, nodes.ClassDef)
+                        a
+                        for a in exception.ancestors()
+                        if isinstance(a, nodes.ClassDef)
                     ]
 
                     for previous_exc in exceptions_classes:
