@@ -90,9 +90,8 @@ class RecommendationChecker(checkers.BaseChecker):
             return
 
         comp_ancestor = utils.get_node_first_ancestor_of_type(node, nodes.Compare)
-        if (
-            isinstance(node.parent, (nodes.For, nodes.Comprehension))
-            or comp_ancestor
+        if isinstance(node.parent, (nodes.For, nodes.Comprehension)) or (
+            comp_ancestor
             and any(
                 op
                 for op, comparator in comp_ancestor.ops
@@ -100,14 +99,11 @@ class RecommendationChecker(checkers.BaseChecker):
                 and (comparator in node.node_ancestors() or comparator is node)
             )
         ):
-            inferred = utils.safe_infer(node.func)
-            if not isinstance(inferred, astroid.BoundMethod) or not isinstance(
-                inferred.bound, nodes.Dict
-            ):
-                return
-            self.add_message(
-                "consider-iterating-dictionary", node=node, confidence=INFERENCE
-            )
+            match utils.safe_infer(node.func):
+                case astroid.BoundMethod(bound=nodes.Dict()):
+                    self.add_message(
+                        "consider-iterating-dictionary", node=node, confidence=INFERENCE
+                    )
 
     def _check_use_maxsplit_arg(self, node: nodes.Call) -> None:
         """Add message when accessing first or last elements of a str.split() or
@@ -214,15 +210,14 @@ class RecommendationChecker(checkers.BaseChecker):
             return
 
         # Is it a proper len call?
-        if not isinstance(node.iter.args[-1], nodes.Call):
-            return
-        second_func = node.iter.args[-1].func
-        if not self._is_builtin(second_func, "len"):
-            return
-        len_args = node.iter.args[-1].args
-        if not len_args or len(len_args) != 1:
-            return
-        iterating_object = len_args[0]
+        match node.iter.args:
+            case [
+                *_,
+                nodes.Call(func=second_func, args=[iterating_object]),
+            ] if self._is_builtin(second_func, "len"):
+                pass
+            case _:
+                return
         if isinstance(iterating_object, nodes.Name):
             expected_subscript_val_type = nodes.Name
         elif isinstance(iterating_object, nodes.Attribute):
@@ -231,12 +226,9 @@ class RecommendationChecker(checkers.BaseChecker):
             return
         # If we're defining __iter__ on self, enumerate won't work
         scope = node.scope()
-        if (
-            isinstance(iterating_object, nodes.Name)
-            and iterating_object.name == "self"
-            and scope.name == "__iter__"
-        ):
-            return
+        match iterating_object:
+            case nodes.Name(name="self") if scope.name == "__iter__":
+                return
 
         # Verify that the body of the for loop uses a subscript
         # with the object that was iterated. This uses some heuristics
@@ -257,10 +249,14 @@ class RecommendationChecker(checkers.BaseChecker):
                     # name for the iterating object was used.
                     continue
                 if value.name == node.target.name and (
-                    isinstance(subscript.value, nodes.Name)
-                    and iterating_object.name == subscript.value.name
-                    or isinstance(subscript.value, nodes.Attribute)
-                    and iterating_object.attrname == subscript.value.attrname
+                    (
+                        isinstance(subscript.value, nodes.Name)
+                        and iterating_object.name == subscript.value.name
+                    )
+                    or (
+                        isinstance(subscript.value, nodes.Attribute)
+                        and iterating_object.attrname == subscript.value.attrname
+                    )
                 ):
                     self.add_message("consider-using-enumerate", node=node)
                     return
@@ -301,7 +297,8 @@ class RecommendationChecker(checkers.BaseChecker):
                 if (
                     isinstance(subscript.parent, nodes.Assign)
                     and subscript in subscript.parent.targets
-                    or isinstance(subscript.parent, nodes.AugAssign)
+                ) or (
+                    isinstance(subscript.parent, nodes.AugAssign)
                     and subscript == subscript.parent.target
                 ):
                     # Ignore this subscript if it is the target of an assignment
@@ -395,10 +392,7 @@ class RecommendationChecker(checkers.BaseChecker):
                     # If star expressions with more than 1 element are being used
                     if isinstance(arg, nodes.Starred):
                         inferred = utils.safe_infer(arg.value)
-                        if (
-                            isinstance(inferred, astroid.List)
-                            and len(inferred.elts) > 1
-                        ):
+                        if isinstance(inferred, nodes.List) and len(inferred.elts) > 1:
                             return
                     # Backslashes can't be in f-string expressions
                     if "\\" in arg.as_string():
@@ -443,13 +437,10 @@ class RecommendationChecker(checkers.BaseChecker):
             if "{" in node.parent.left.value or "}" in node.parent.left.value:
                 return
 
-            inferred_right = utils.safe_infer(node.parent.right)
-
             # If dicts or lists of length > 1 are used
-            if isinstance(inferred_right, nodes.Dict) and len(inferred_right.items) > 1:
-                return
-            if isinstance(inferred_right, nodes.List) and len(inferred_right.elts) > 1:
-                return
+            match utils.safe_infer(node.parent.right):
+                case nodes.Dict(items=items) | nodes.List(elts=items) if len(items) > 1:
+                    return
 
             # If all tests pass, then raise message
             self.add_message(
